@@ -1,7 +1,14 @@
 #if defined HAVE_CONFIG_H
 # include "config.h"
 #endif	/* HAVE_CONFIG_H */
-#include "dt-core.h"
+#include "strops.h"
+#include "strops.c"
+#include "token.h"
+#include "token.c"
+#include "date-core.h"
+#include "date-core.c"
+#include "dt-locale.h"
+#include "dt-locale.c"
 
 static unsigned int
 super(void)
@@ -17,7 +24,7 @@ super(void)
 				x.m = m;
 				x.d = d;
 				w = __ymd_get_wday(x);
-				res += y * m * w + d;
+				res += y * m * (w == DT_SUNDAY ? 0 : w) + d;
 			}
 		}
 	}
